@@ -3,9 +3,12 @@ import sys
 import warnings
 from logging import config
 from .swifter import SeriesAccessor, DataFrameAccessor
-from .parallel_accessor import register_parallel_dataframe_accessor, register_parallel_series_accessor, register_modin
+from .parallel_accessor import (
+    register_parallel_dataframe_accessor,
+    register_parallel_series_accessor,
+    register_modin,
+)
 
-config.dictConfig({"version": 1, "disable_existing_loggers": True})
 warnings.filterwarnings("ignore", category=FutureWarning)
 
 if "modin.pandas" in sys.modules:
@@ -18,4 +21,4 @@ __all__ = [
     "register_parallel_series_accessor",
     "register_modin",
 ]
-__version__ = "1.0.2"
+__version__ = "1.1.2"
