@@ -5,15 +5,13 @@ import subprocess
 import time
 import logging
 import warnings
-from math import ceil
-from psutil import cpu_count, virtual_memory
+from psutil import cpu_count
 
 import numpy as np
 import numpy.testing as npt
 import pandas as pd
 import swifter
 
-from math import ceil, isclose
 from tqdm.auto import tqdm
 
 
@@ -21,17 +19,19 @@ LOG = logging.getLogger(__name__)
 LOG.setLevel(logging.INFO)
 ch = logging.StreamHandler()
 ch.setLevel(logging.INFO)
-formatter = logging.Formatter("%(asctime)-8s.%(msecs)03d %(levelname)-8s %(name)s:%(lineno)-3s %(message)s")
+formatter = logging.Formatter(
+    "%(asctime)-8s.%(msecs)03d %(levelname)-8s %(name)s:%(lineno)-3s %(message)s"
+)
 ch.setFormatter(formatter)
 LOG.addHandler(ch)
 
 
 def math_vec_square(x):
-    return x ** 2
+    return x**2
 
 
 def math_foo(x, compare_to=1):
-    return x ** 2 if x < compare_to else x ** (1 / 2)
+    return x**2 if x < compare_to else x ** (1 / 2)
 
 
 def math_vec_multiply(row):
@@ -122,10 +122,12 @@ class TestSetup(TestSwifter):
                 pd.DataFrame().swifter,
                 pd.Series().swifter,
                 pd.DataFrame(
-                    {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
+                    {"x": np.arange(0, 10)},
+                    index=pd.date_range("2019-01-1", "2020-01-1", periods=10),
                 ).swifter.rolling("1d"),
                 pd.DataFrame(
-                    {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
+                    {"x": np.arange(0, 10)},
+                    index=pd.date_range("2019-01-1", "2020-01-1", periods=10),
                 ).swifter.resample("3T"),
             ],
             [None, 1000, 1001, 1002],
@@ -138,50 +140,6 @@ class TestSetup(TestSwifter):
             if set_npartitions is not None:
                 self.assertNotEqual(before, actual)
 
-    def test_set_ray_compute(self):
-        LOG.info("test_set_ray_compute")
-        for swifter_df, set_ray_memory, expected in zip(
-            [
-                pd.DataFrame().swifter,
-                pd.Series().swifter,
-                pd.DataFrame(
-                    {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
-                ).swifter.rolling("1d"),
-                pd.DataFrame(
-                    {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
-                ).swifter.resample("3T"),
-            ],
-            [0.5, 0.99, 100000000],
-            [
-                ceil(virtual_memory().available * 0.5),
-                ceil(virtual_memory().available * 0.99),
-                100000000,
-            ],
-        ):
-            before = swifter_df._ray_memory
-            swifter_df.set_ray_compute(num_cpus=1, memory=set_ray_memory)
-            actual = swifter_df._ray_memory
-            self.assertTrue(isclose(actual, expected, rel_tol=0.2))
-            self.assertNotEqual(before, actual)
-
-    def test_cant_set_ray_memory_OOM(self):
-        LOG.info("test_cant_set_ray_memory_OOM")
-        for swifter_df, set_ray_memory in zip(
-            [
-                pd.DataFrame().swifter,
-                pd.Series().swifter,
-                pd.DataFrame(
-                    {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
-                ).swifter.rolling("1d"),
-                pd.DataFrame(
-                    {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
-                ).swifter.resample("3T"),
-            ],
-            [1e100, 1e100, 1e100, 1e100],
-        ):
-            with self.assertRaises(MemoryError):
-                swifter_df.set_ray_compute(memory=set_ray_memory)
-
     def test_set_dask_threshold(self):
         LOG.info("test_set_dask_threshold")
         expected = 1000
@@ -189,10 +147,12 @@ class TestSetup(TestSwifter):
             pd.DataFrame().swifter,
             pd.Series().swifter,
             pd.DataFrame(
-                {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
+                {"x": np.arange(0, 10)},
+                index=pd.date_range("2019-01-1", "2020-01-1", periods=10),
             ).swifter.rolling("1d"),
             pd.DataFrame(
-                {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
+                {"x": np.arange(0, 10)},
+                index=pd.date_range("2019-01-1", "2020-01-1", periods=10),
             ).swifter.resample("3T"),
         ]:
             before = swifter_df._dask_threshold
@@ -208,10 +168,12 @@ class TestSetup(TestSwifter):
             pd.DataFrame().swifter,
             pd.Series().swifter,
             pd.DataFrame(
-                {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
+                {"x": np.arange(0, 10)},
+                index=pd.date_range("2019-01-1", "2020-01-1", periods=10),
             ).swifter.rolling("1d"),
             pd.DataFrame(
-                {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
+                {"x": np.arange(0, 10)},
+                index=pd.date_range("2019-01-1", "2020-01-1", periods=10),
             ).swifter.resample("3T"),
         ]:
             before = swifter_df._scheduler
@@ -227,10 +189,12 @@ class TestSetup(TestSwifter):
             pd.DataFrame().swifter,
             pd.Series().swifter,
             pd.DataFrame(
-                {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
+                {"x": np.arange(0, 10)},
+                index=pd.date_range("2019-01-1", "2020-01-1", periods=10),
             ).swifter.rolling("1d"),
             pd.DataFrame(
-                {"x": np.arange(0, 10)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=10)
+                {"x": np.arange(0, 10)},
+                index=pd.date_range("2019-01-1", "2020-01-1", periods=10),
             ).swifter.resample("3T"),
         ]:
             before = swifter_df._progress_bar
@@ -257,11 +221,14 @@ class TestSetup(TestSwifter):
                 "-c",
                 "import pandas as pd; import numpy as np; import swifter; "
                 + "df = pd.DataFrame({'x': np.random.normal(size=4)}, dtype='float32'); "
-                + "df.swifter.progress_bar(enable=False).apply(lambda x: print(x.values))",
+                + "df.swifter.progress_bar(enable=False)"
+                + ".apply(lambda x: print(x.values))",
             ],
             stderr=subprocess.STDOUT,
         )
-        self.assertEqual(len(print_messages.decode("utf-8").rstrip("\n").split("\n")), 1)
+        self.assertEqual(
+            len(print_messages.decode("utf-8").rstrip("\n").split("\n")), 1
+        )
 
 
 class TestPandasSeries(TestSwifter):
@@ -278,7 +245,9 @@ class TestPandasSeries(TestSwifter):
         series = df["x"]
         tqdm.pandas(desc="Pandas Vec math apply ~ Series")
         pd_val = series.progress_apply(math_foo, compare_to=1)
-        swifter_val = series.swifter.progress_bar(desc="Vec math apply ~ Series").apply(math_foo, compare_to=1)
+        swifter_val = series.swifter.progress_bar(desc="Vec math apply ~ Series").apply(
+            math_foo, compare_to=1
+        )
         self.assertEqual(pd_val, swifter_val)  # equality test
 
     def test_nonvectorized_math_apply_on_small_series_no_progress_bar(self):
@@ -286,7 +255,9 @@ class TestPandasSeries(TestSwifter):
         df = pd.DataFrame({"x": np.random.normal(size=1000)})
         series = df["x"]
         pd_val = series.apply(math_foo, compare_to=1)
-        swifter_val = series.swifter.progress_bar(enable=False).apply(math_foo, compare_to=1)
+        swifter_val = series.swifter.progress_bar(enable=False).apply(
+            math_foo, compare_to=1
+        )
         self.assertEqual(pd_val, swifter_val)  # equality test
 
     def test_vectorized_math_apply_on_large_series(self):
@@ -355,22 +326,33 @@ class TestPandasDataFrame(TestSwifter):
 
     def test_nonvectorized_math_apply_on_small_dataframe(self):
         LOG.info("test_nonvectorized_math_apply_on_small_dataframe")
-        df = pd.DataFrame({"x": np.random.normal(size=1000), "y": np.random.uniform(size=1000)})
+        df = pd.DataFrame(
+            {"x": np.random.normal(size=1000), "y": np.random.uniform(size=1000)}
+        )
         tqdm.pandas(desc="Pandas Nonvec math apply ~ DF")
         pd_val = df.progress_apply(math_agg_foo)
-        swifter_val = df.swifter.progress_bar(desc="Vec math apply ~ DF").apply(math_agg_foo)
+        swifter_val = df.swifter.progress_bar(desc="Vec math apply ~ DF").apply(
+            math_agg_foo
+        )
         self.assertEqual(pd_val, swifter_val)  # equality test
 
     def test_nonvectorized_math_apply_on_small_dataframe_no_progress_bar(self):
         LOG.info("test_nonvectorized_math_apply_on_small_dataframe_no_progress_bar")
-        df = pd.DataFrame({"x": np.random.normal(size=1000), "y": np.random.uniform(size=1000)})
+        df = pd.DataFrame(
+            {"x": np.random.normal(size=1000), "y": np.random.uniform(size=1000)}
+        )
         pd_val = df.apply(math_agg_foo)
         swifter_val = df.swifter.progress_bar(enable=False).apply(math_agg_foo)
         self.assertEqual(pd_val, swifter_val)  # equality test
 
     def test_vectorized_math_apply_on_large_dataframe(self):
         LOG.info("test_vectorized_math_apply_on_large_dataframe")
-        df = pd.DataFrame({"x": np.random.normal(size=1_000_000), "y": np.random.uniform(size=1_000_000)})
+        df = pd.DataFrame(
+            {
+                "x": np.random.normal(size=1_000_000),
+                "y": np.random.uniform(size=1_000_000),
+            }
+        )
 
         tqdm.pandas(desc="Pandas Vec math apply ~ DF")
         start_pd = time.time()
@@ -380,7 +362,9 @@ class TestPandasDataFrame(TestSwifter):
 
         start_swifter = time.time()
         swifter_val = (
-            df.swifter.set_npartitions(4).progress_bar(desc="Vec math apply ~ DF").apply(math_vec_multiply, axis=1)
+            df.swifter.set_npartitions(4)
+            .progress_bar(desc="Vec math apply ~ DF")
+            .apply(math_vec_multiply, axis=1)
         )
         end_swifter = time.time()
         swifter_time = end_swifter - start_swifter
@@ -391,7 +375,9 @@ class TestPandasDataFrame(TestSwifter):
 
     def test_nonvectorized_math_apply_on_large_dataframe_broadcast(self):
         LOG.info("test_nonvectorized_math_apply_on_large_dataframe_broadcast")
-        df = pd.DataFrame({"x": np.random.normal(size=250_000), "y": np.random.uniform(size=250_000)})
+        df = pd.DataFrame(
+            {"x": np.random.normal(size=500_000), "y": np.random.uniform(size=500_000)}
+        )
 
         tqdm.pandas(desc="Pandas Nonvec math apply + broadcast ~ DF")
         start_pd = time.time()
@@ -414,7 +400,9 @@ class TestPandasDataFrame(TestSwifter):
 
     def test_nonvectorized_math_apply_on_large_dataframe_reduce(self):
         LOG.info("test_nonvectorized_math_apply_on_large_dataframe_reduce")
-        df = pd.DataFrame({"x": np.random.normal(size=250_000), "y": np.random.uniform(size=250_000)})
+        df = pd.DataFrame(
+            {"x": np.random.normal(size=250_000), "y": np.random.uniform(size=250_000)}
+        )
 
         tqdm.pandas(desc="Pandas Nonvec math apply + reduce ~ DF")
         start_pd = time.time()
@@ -437,7 +425,12 @@ class TestPandasDataFrame(TestSwifter):
 
     def test_nonvectorized_text_dask_apply_on_large_dataframe(self):
         LOG.info("test_nonvectorized_text_dask_apply_on_large_dataframe")
-        df = pd.DataFrame({"letter": ["A", "B", "C", "D", "E"] * 200_000, "value": np.random.normal(size=1_000_000)})
+        df = pd.DataFrame(
+            {
+                "letter": ["A", "B", "C", "D", "E"] * 200_000,
+                "value": np.random.normal(size=1_000_000),
+            }
+        )
 
         tqdm.pandas(desc="Pandas Nonvec text apply ~ DF")
         start_pd = time.time()
@@ -459,63 +452,14 @@ class TestPandasDataFrame(TestSwifter):
         if self.ncores > 1:  # speed test
             self.assertLess(swifter_time, pd_time)
 
-    @run_if_modin_installed
-    def test_nonvectorized_text_modin_apply_on_large_dataframe(self):
-        LOG.info("test_nonvectorized_text_modin_apply_on_large_dataframe")
-        self.modinSetUp()
-        df = pd.DataFrame({"letter": ["I", "You", "We"] * 1_000_000, "value": ["want to break free"] * 3_000_000})
-
-        tqdm.pandas(desc="Pandas Nonvec text apply ~ DF")
-        start_pd = time.time()
-        pd_val = df.progress_apply(clean_text_foo, axis=1)
-        end_pd = time.time()
-        pd_time = end_pd - start_pd
-
-        start_swifter = time.time()
-        swifter_val = (
-            df.swifter.allow_dask_on_strings(False)
-            .set_npartitions(4)
-            .set_ray_compute(num_cpus=2 if self.ncores >= 2 else 1, memory=0.25)
-            .progress_bar(desc="Nonvec Modin text apply ~ DF")
-            .apply(clean_text_foo, axis=1)
-        )
-        end_swifter = time.time()
-        swifter_time = end_swifter - start_swifter
-
-        self.assertEqual(pd_val, swifter_val)  # equality test
-        if self.ncores > 1:  # speed test
-            self.assertLess(swifter_time, pd_time)
-
-    @run_if_modin_installed
-    def test_nonvectorized_text_modin_apply_on_large_dataframe_returns_series(self):
-        LOG.info("test_nonvectorized_text_modin_apply_on_large_dataframe_returns_series")
-        self.modinSetUp()
-        df = pd.DataFrame({"str_date": ["2000/01/01 00:00:00"] * 1_000_000})
-
-        tqdm.pandas(desc="Pandas Nonvec text apply ~ DF -> Srs")
-        start_pd = time.time()
-        pd_val = df.progress_apply(lambda row: row["str_date"].split()[0], axis=1)
-        end_pd = time.time()
-        pd_time = end_pd - start_pd
-
-        start_swifter = time.time()
-        swifter_val = (
-            df.swifter.allow_dask_on_strings(False)
-            .set_npartitions(4)
-            .set_ray_compute(num_cpus=2 if self.ncores >= 2 else 1, memory=0.25)
-            .progress_bar(desc="Nonvec Modin text apply ~ DF -> Srs")
-            .apply(lambda row: row["str_date"].split()[0], axis=1)
-        )
-        end_swifter = time.time()
-        swifter_time = end_swifter - start_swifter
-
-        self.assertEqual(pd_val, swifter_val)  # equality test
-        if self.ncores > 1:  # speed test
-            self.assertLess(swifter_time, pd_time)
-
     def test_vectorized_math_applymap_on_large_dataframe(self):
         LOG.info("test_vectorized_math_applymap_on_large_dataframe")
-        df = pd.DataFrame({"x": np.random.normal(size=1_000_000), "y": np.random.uniform(size=1_000_000)})
+        df = pd.DataFrame(
+            {
+                "x": np.random.normal(size=1_000_000),
+                "y": np.random.uniform(size=1_000_000),
+            }
+        )
 
         tqdm.pandas(desc="Pandas Vec math applymap ~ DF")
         start_pd = time.time()
@@ -525,7 +469,9 @@ class TestPandasDataFrame(TestSwifter):
 
         start_swifter = time.time()
         swifter_val = (
-            df.swifter.set_npartitions(4).progress_bar(desc="Vec math applymap ~ DF").applymap(math_vec_square)
+            df.swifter.set_npartitions(4)
+            .progress_bar(desc="Vec math applymap ~ DF")
+            .applymap(math_vec_square)
         )
         end_swifter = time.time()
         swifter_time = end_swifter - start_swifter
@@ -536,7 +482,12 @@ class TestPandasDataFrame(TestSwifter):
 
     def test_nonvectorized_math_applymap_on_large_dataframe(self):
         LOG.info("test_nonvectorized_math_applymap_on_large_dataframe")
-        df = pd.DataFrame({"x": np.random.normal(size=5_000_000), "y": np.random.uniform(size=5_000_000)})
+        df = pd.DataFrame(
+            {
+                "x": np.random.normal(size=5_000_000),
+                "y": np.random.uniform(size=5_000_000),
+            }
+        )
 
         tqdm.pandas(desc="Pandas Nonvec math applymap ~ DF")
         start_pd = time.time()
@@ -545,7 +496,11 @@ class TestPandasDataFrame(TestSwifter):
         pd_time = end_pd - start_pd
 
         start_swifter = time.time()
-        swifter_val = df.swifter.set_npartitions(4).progress_bar(desc="Nonvec math applymap ~ DF").applymap(math_foo)
+        swifter_val = (
+            df.swifter.set_npartitions(4)
+            .progress_bar(desc="Nonvec math applymap ~ DF")
+            .applymap(math_foo)
+        )
         end_swifter = time.time()
         swifter_time = end_swifter - start_swifter
 
@@ -555,14 +510,18 @@ class TestPandasDataFrame(TestSwifter):
 
     def test_nonvectorized_math_applymap_on_small_dataframe(self):
         LOG.info("test_nonvectorized_math_applymap_on_small_dataframe")
-        df = pd.DataFrame({"x": np.random.normal(size=1000), "y": np.random.uniform(size=1000)})
+        df = pd.DataFrame(
+            {"x": np.random.normal(size=1000), "y": np.random.uniform(size=1000)}
+        )
         pd_val = df.applymap(math_foo)
         swifter_val = df.swifter.set_npartitions(4).applymap(math_foo)
         self.assertEqual(pd_val, swifter_val)  # equality test
 
     def test_nonvectorized_math_applymap_on_small_dataframe_no_progress_bar(self):
         LOG.info("test_nonvectorized_math_applymap_on_small_dataframe_no_progress_bar")
-        df = pd.DataFrame({"x": np.random.normal(size=1000), "y": np.random.uniform(size=1000)})
+        df = pd.DataFrame(
+            {"x": np.random.normal(size=1000), "y": np.random.uniform(size=1000)}
+        )
         pd_val = df.applymap(math_foo)
         swifter_val = df.swifter.progress_bar(enable=False).applymap(math_foo)
         self.assertEqual(pd_val, swifter_val)  # equality test
@@ -573,19 +532,26 @@ class TestPandasTransformation(TestSwifter):
         LOG.info("test_rolling_apply_on_empty_dataframe")
         df = pd.DataFrame(columns=["x", "y"])
         pd_val = df.rolling(1).apply(math_agg_foo, raw=True)
-        swifter_val = df.swifter.set_npartitions(4).rolling(1).apply(math_agg_foo, raw=True)
+        swifter_val = (
+            df.swifter.set_npartitions(4).rolling(1).apply(math_agg_foo, raw=True)
+        )
         self.assertEqual(pd_val, swifter_val)  # equality test
 
     def test_resample_apply_on_empty_dataframe(self):
         LOG.info("test_resample_apply_on_empty_dataframe")
-        df = pd.DataFrame(columns=["x", "y"], index=pd.date_range(start="2020/01/01", periods=0))
+        df = pd.DataFrame(
+            columns=["x", "y"], index=pd.date_range(start="2020/01/01", periods=0)
+        )
         pd_val = df.resample("1d").apply(math_agg_foo)
         swifter_val = df.swifter.set_npartitions(4).resample("1d").apply(math_agg_foo)
         self.assertEqual(pd_val, swifter_val)  # equality test
 
     def test_nonvectorized_math_apply_on_small_rolling_dataframe(self):
         LOG.info("test_nonvectorized_math_apply_on_small_rolling_dataframe")
-        df = pd.DataFrame({"x": np.arange(0, 1000)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=1000))
+        df = pd.DataFrame(
+            {"x": np.arange(0, 1000)},
+            index=pd.date_range("2019-01-1", "2020-01-1", periods=1000),
+        )
         pd_val = df.rolling("1d").apply(math_agg_foo, raw=True)
         swifter_val = (
             df.swifter.set_npartitions(4)
@@ -596,18 +562,27 @@ class TestPandasTransformation(TestSwifter):
         self.assertEqual(pd_val, swifter_val)  # equality test
 
     def test_nonvectorized_math_apply_on_small_rolling_dataframe_no_progress_bar(self):
-        LOG.info("test_nonvectorized_math_apply_on_small_rolling_dataframe_no_progress_bar")
-        df = pd.DataFrame({"x": np.arange(0, 1000)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=1000))
+        LOG.info(
+            "test_nonvectorized_math_apply_on_small_rolling_dataframe_no_progress_bar"
+        )
+        df = pd.DataFrame(
+            {"x": np.arange(0, 1000)},
+            index=pd.date_range("2019-01-1", "2020-01-1", periods=1000),
+        )
         pd_val = df.rolling("1d").apply(math_agg_foo, raw=True)
         swifter_val = (
-            df.swifter.set_npartitions(4).rolling("1d").progress_bar(enable=False).apply(math_agg_foo, raw=True)
+            df.swifter.set_npartitions(4)
+            .rolling("1d")
+            .progress_bar(enable=False)
+            .apply(math_agg_foo, raw=True)
         )
         self.assertEqual(pd_val, swifter_val)  # equality test
 
     def test_vectorized_math_apply_on_large_rolling_dataframe(self):
         LOG.info("test_vectorized_math_apply_on_large_rolling_dataframe")
         df = pd.DataFrame(
-            {"x": np.arange(0, 1_000_000)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=1_000_000)
+            {"x": np.arange(0, 1_000_000)},
+            index=pd.date_range("2019-01-1", "2020-01-1", periods=1_000_000),
         )
         pd_val = df.rolling("1d").apply(max, raw=True)
         swifter_val = (
@@ -621,7 +596,8 @@ class TestPandasTransformation(TestSwifter):
     def test_nonvectorized_math_apply_on_large_rolling_dataframe(self):
         LOG.info("test_nonvectorized_math_apply_on_large_rolling_dataframe")
         df = pd.DataFrame(
-            {"x": np.arange(0, 7_000_000)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=7_000_000)
+            {"x": np.arange(0, 10_000_000)},
+            index=pd.date_range("2019-01-1", "2020-01-1", periods=10_000_000),
         )
 
         start_pd = time.time()
@@ -631,7 +607,7 @@ class TestPandasTransformation(TestSwifter):
 
         start_swifter = time.time()
         swifter_val = (
-            df.swifter.set_npartitions(7)
+            df.swifter.set_npartitions(10)
             .rolling("3T")
             .progress_bar(desc="Nonvec math apply ~ Rolling DF")
             .apply(math_agg_foo, raw=True)
@@ -645,7 +621,10 @@ class TestPandasTransformation(TestSwifter):
 
     def test_nonvectorized_math_apply_on_small_resampler_dataframe(self):
         LOG.info("test_nonvectorized_math_apply_on_small_resampler_dataframe")
-        df = pd.DataFrame({"x": np.arange(0, 1000)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=1000))
+        df = pd.DataFrame(
+            {"x": np.arange(0, 1000)},
+            index=pd.date_range("2019-01-1", "2020-01-1", periods=1000),
+        )
         pd_val = df.resample("1M").apply(math_agg_foo)
         swifter_val = (
             df.swifter.set_npartitions(4)
@@ -658,7 +637,8 @@ class TestPandasTransformation(TestSwifter):
     def test_nonvectorized_math_apply_on_large_resampler_dataframe(self):
         LOG.info("test_nonvectorized_math_apply_on_large_resampler_dataframe")
         df = pd.DataFrame(
-            {"x": np.arange(0, 1_000_000)}, index=pd.date_range("2019-01-1", "2020-01-1", periods=1_000_000)
+            {"x": np.arange(0, 1_000_000)},
+            index=pd.date_range("2019-01-1", "2020-01-1", periods=1_000_000),
         )
 
         start_pd = time.time()
@@ -739,7 +719,9 @@ class TestModinSeries(TestSwifter):
         df = md.Series(np.random.uniform(size=20_000_000), name="x")
         start_md = time.time()
         md_val = df.apply(math_vec_square, axis=0)
-        md_pd_val = md_val._to_pandas()  # We have to bring it into pandas to confirm swifter apply speed is quicker
+        md_pd_val = (
+            md_val._to_pandas()
+        )  # We have to bring it into pandas to confirm swifter apply speed is quicker
         end_md = time.time()
         md_time = end_md - start_md
 
@@ -752,7 +734,9 @@ class TestModinSeries(TestSwifter):
         swifter_time = end_swifter - start_swifter
 
         self.assertEqual(md_val, swifter_val)  # equality test
-        self.assertEqual(md_pd_val, swifter_pd_val)  # equality test after converting to pandas
+        self.assertEqual(
+            md_pd_val, swifter_pd_val
+        )  # equality test after converting to pandas
         self.assertLess(swifter_time, md_time)  # speed test
 
 
@@ -803,7 +787,12 @@ class TestModinDataFrame(TestSwifter):
     def test_nonvectorized_modin_apply_on_small_dataframe(self):
         LOG.info("test_nonvectorized_modin_apply_on_small_dataframe")
         md = self.modinSetUp()
-        df = md.DataFrame({"letter": ["A", "B", "C", "D", "E"] * 200_000, "value": np.random.normal(size=1_000_000)})
+        df = md.DataFrame(
+            {
+                "letter": ["A", "B", "C", "D", "E"] * 200_000,
+                "value": np.random.normal(size=1_000_000),
+            }
+        )
         md_val = df.apply(text_foo, axis=1)
         swifter_val = df.swifter.set_npartitions(4).apply(text_foo, axis=1)
         self.assertEqual(md_val, swifter_val)  # equality test
@@ -811,10 +800,17 @@ class TestModinDataFrame(TestSwifter):
     def test_vectorized_modin_apply_on_large_dataframe(self):
         LOG.info("test_vectorized_modin_apply_on_large_dataframe")
         md = self.modinSetUp()
-        df = md.DataFrame({"x": np.random.normal(size=1_000_000), "y": np.random.uniform(size=1_000_000)})
+        df = md.DataFrame(
+            {
+                "x": np.random.normal(size=1_000_000),
+                "y": np.random.uniform(size=1_000_000),
+            }
+        )
         start_md = time.time()
         md_val = df.apply(math_vec_square, axis=1)
-        md_pd_val = md_val._to_pandas()  # We have to bring it into pandas to confirm swifter apply speed is quicker
+        md_pd_val = (
+            md_val._to_pandas()
+        )  # We have to bring it into pandas to confirm swifter apply speed is quicker
         end_md = time.time()
         md_time = end_md - start_md
 
@@ -827,5 +823,7 @@ class TestModinDataFrame(TestSwifter):
         swifter_time = end_swifter - start_swifter
 
         self.assertEqual(md_val, swifter_val)  # equality test
-        self.assertEqual(md_pd_val, swifter_pd_val)  # equality test after converting to pandas
+        self.assertEqual(
+            md_pd_val, swifter_pd_val
+        )  # equality test after converting to pandas
         self.assertLess(swifter_time, md_time)  # speed test
